/*
Copyright 2019 The Tekton Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"context"
	"time"

	v1beta1 "github.com/tektoncd/triggers/pkg/apis/triggers/v1beta1"
	scheme "github.com/tektoncd/triggers/pkg/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// TriggerBindingsGetter has a method to return a TriggerBindingInterface.
// A group's client should implement this interface.
type TriggerBindingsGetter interface {
	TriggerBindings(namespace string) TriggerBindingInterface
}

// TriggerBindingInterface has methods to work with TriggerBinding resources.
type TriggerBindingInterface interface {
	Create(ctx context.Context, triggerBinding *v1beta1.TriggerBinding, opts v1.CreateOptions) (*v1beta1.TriggerBinding, error)
	Update(ctx context.Context, triggerBinding *v1beta1.TriggerBinding, opts v1.UpdateOptions) (*v1beta1.TriggerBinding, error)
	UpdateStatus(ctx context.Context, triggerBinding *v1beta1.TriggerBinding, opts v1.UpdateOptions) (*v1beta1.TriggerBinding, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.TriggerBinding, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1beta1.TriggerBindingList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.TriggerBinding, err error)
	TriggerBindingExpansion
}

// triggerBindings implements TriggerBindingInterface
type triggerBindings struct {
	client rest.Interface
	ns     string
}

// newTriggerBindings returns a TriggerBindings
func newTriggerBindings(c *TriggersV1beta1Client, namespace string) *triggerBindings {
	return &triggerBindings{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the triggerBinding, and returns the corresponding triggerBinding object, and an error if there is any.
func (c *triggerBindings) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.TriggerBinding, err error) {
	result = &v1beta1.TriggerBinding{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("triggerbindings").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of TriggerBindings that match those selectors.
func (c *triggerBindings) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.TriggerBindingList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.TriggerBindingList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("triggerbindings").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested triggerBindings.
func (c *triggerBindings) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("triggerbindings").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a triggerBinding and creates it.  Returns the server's representation of the triggerBinding, and an error, if there is any.
func (c *triggerBindings) Create(ctx context.Context, triggerBinding *v1beta1.TriggerBinding, opts v1.CreateOptions) (result *v1beta1.TriggerBinding, err error) {
	result = &v1beta1.TriggerBinding{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("triggerbindings").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(triggerBinding).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a triggerBinding and updates it. Returns the server's representation of the triggerBinding, and an error, if there is any.
func (c *triggerBindings) Update(ctx context.Context, triggerBinding *v1beta1.TriggerBinding, opts v1.UpdateOptions) (result *v1beta1.TriggerBinding, err error) {
	result = &v1beta1.TriggerBinding{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("triggerbindings").
		Name(triggerBinding.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(triggerBinding).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *triggerBindings) UpdateStatus(ctx context.Context, triggerBinding *v1beta1.TriggerBinding, opts v1.UpdateOptions) (result *v1beta1.TriggerBinding, err error) {
	result = &v1beta1.TriggerBinding{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("triggerbindings").
		Name(triggerBinding.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(triggerBinding).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the triggerBinding and deletes it. Returns an error if one occurs.
func (c *triggerBindings) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("triggerbindings").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *triggerBindings) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("triggerbindings").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched triggerBinding.
func (c *triggerBindings) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.TriggerBinding, err error) {
	result = &v1beta1.TriggerBinding{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("triggerbindings").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
